aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-05-21 17:55:49 +0200
committerMattias Andrée <maandree@operamail.com>2014-05-21 17:56:42 +0200
commite68550f5b18186bfbb2504b9df03ba32356b6cf4 (patch)
treedab217572c027633ccdb051c442ea0b5df1faf8e
parentm (diff)
downloadlibgamma-e68550f5b18186bfbb2504b9df03ba32356b6cf4.tar.gz
libgamma-e68550f5b18186bfbb2504b9df03ba32356b6cf4.tar.bz2
libgamma-e68550f5b18186bfbb2504b9df03ba32356b6cf4.tar.xz
m
Signed-off-by: Mattias Andrée <maandree@operamail.com>
-rw-r--r--src/gamma-linux-drm.h (renamed from src/gamma-drm.h)82
-rw-r--r--src/gamma-w32-gdi.h (renamed from src/gamma-w32gdi.h)80
-rw-r--r--src/libgamma-facade.c88
3 files changed, 125 insertions, 125 deletions
diff --git a/src/gamma-w32gdi.h b/src/gamma-w32-gdi.h
index d1299bf..d53b292 100644
--- a/src/gamma-w32gdi.h
+++ b/src/gamma-w32-gdi.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_W32GDI_H
-#define LIBGAMMA_GAMMA_W32GDI_H
+#ifndef LIBGAMMA_GAMMA_W32_GDI_H
+#define LIBGAMMA_GAMMA_W32_GDI_H
#ifndef HAVE_GAMMA_METHOD_W32_GDI
-# error Compiling gamma-w32gdi without HAVE_GAMMA_METHOD_W32_GDI
+# error Compiling gamma-w32-gdi without HAVE_GAMMA_METHOD_W32_GDI
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_w32gdi_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_w32_gdi_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,15 +47,15 @@ void libgamma_w32gdi_method_capabilities(libgamma_method_capabilities_t* restric
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_site_initialise(libgamma_site_state_t* restrict this,
- char* restrict site);
+int libgamma_w32_gdi_site_initialise(libgamma_site_state_t* restrict this,
+ char* restrict site);
/**
* Release all resources held by a site state
*
* @param this The site state
*/
-void libgamma_w32gdi_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_w32_gdi_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_w32gdi_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_w32_gdi_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,15 +76,15 @@ int libgamma_w32gdi_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_partition_initialise(libgamma_partition_state_t* restrict this,
- libgamma_site_state_t* restrict site, size_t partition);
+int libgamma_w32_gdi_partition_initialise(libgamma_partition_state_t* restrict this,
+ libgamma_site_state_t* restrict site, size_t partition);
/**
* Release all resources held by a partition state
*
* @param this The partition state
*/
-void libgamma_w32gdi_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_w32_gdi_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_w32gdi_partition_destroy(libgamma_partition_state_t* restrict this
*
* @param this The partition state
*/
-void libgamma_w32gdi_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_w32_gdi_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_w32gdi_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_w32_gdi_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,15 +113,15 @@ int libgamma_w32gdi_partition_restore(libgamma_partition_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_initialise(libgamma_crtc_state_t* restrict this,
- libgamma_partition_state_t* restrict partition, size_t crtc);
+int libgamma_w32_gdi_crtc_initialise(libgamma_crtc_state_t* restrict this,
+ libgamma_partition_state_t* restrict partition, size_t crtc);
/**
* Release all resources held by a CRTC state
*
* @param this The CRTC state
*/
-void libgamma_w32gdi_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_w32_gdi_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_w32gdi_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_w32gdi_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_w32_gdi_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_w32gdi_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_w32_gdi_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,8 +149,8 @@ int libgamma_w32gdi_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_w32gdi_get_crtc_information(libgamma_crtc_information_t* restrict this,
- libgamma_crtc_state_t* restrict crtc, int32_t fields);
+int libgamma_w32_gdi_get_crtc_information(libgamma_crtc_information_t* restrict this,
+ libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
* Get current the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -160,8 +160,8 @@ int libgamma_w32gdi_get_crtc_information(libgamma_crtc_information_t* restrict t
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t* restrict ramps);
+int libgamma_w32_gdi_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -171,8 +171,8 @@ int libgamma_w32gdi_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t ramps);
+int libgamma_w32_gdi_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t ramps);
/**
@@ -183,8 +183,8 @@ int libgamma_w32gdi_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t* restrict ramps);
+int libgamma_w32_gdi_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 32-bit gamma-depth version
@@ -194,8 +194,8 @@ int libgamma_w32gdi_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t ramps);
+int libgamma_w32_gdi_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t ramps);
/**
@@ -206,8 +206,8 @@ int libgamma_w32gdi_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t* restrict ramps);
+int libgamma_w32_gdi_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 64-bit gamma-depth version
@@ -217,8 +217,8 @@ int libgamma_w32gdi_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t ramps);
+int libgamma_w32_gdi_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t ramps);
/**
@@ -229,8 +229,8 @@ int libgamma_w32gdi_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t* restrict ramps);
+int libgamma_w32_gdi_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `float` version
@@ -240,8 +240,8 @@ int libgamma_w32gdi_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t ramps);
+int libgamma_w32_gdi_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t ramps);
/**
* Get current the gamma ramps for a CRTC, `double` version
@@ -251,8 +251,8 @@ int libgamma_w32gdi_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t* restrict ramps);
+int libgamma_w32_gdi_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `double` version
@@ -262,8 +262,8 @@ int libgamma_w32gdi_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_w32gdi_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t ramps);
+int libgamma_w32_gdi_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t ramps);
#endif
diff --git a/src/libgamma-facade.c b/src/libgamma-facade.c
index 81c6d8a..5111a07 100644
--- a/src/libgamma-facade.c
+++ b/src/libgamma-facade.c
@@ -38,13 +38,13 @@
# endif
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
-# include "gamma-drm.h"
+# include "gamma-linux-drm.h"
# ifndef HAVE_GAMMA_METHODS
# define HAVE_GAMMA_METHODS
# endif
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
-# include "gamma-w32gdi.h"
+# include "gamma-w32-gdi.h"
# ifndef HAVE_GAMMA_METHODS
# define HAVE_GAMMA_METHODS
# endif
@@ -235,12 +235,12 @@ void libgamma_method_capabilities(libgamma_method_capabilities_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- libgamma_drm_method_capabilities(this);
+ libgamma_linux_drm_method_capabilities(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- libgamma_w32gdi_method_capabilities(this);
+ libgamma_w32_gdi_method_capabilities(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
@@ -347,11 +347,11 @@ int libgamma_site_initialise(libgamma_site_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_site_initialise(this, site);
+ return libgamma_linux_drm_site_initialise(this, site);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_site_initialise(this, site);
+ return libgamma_w32_gdi_site_initialise(this, site);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -390,12 +390,12 @@ void libgamma_site_destroy(libgamma_site_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- libgamma_drm_site_destroy(this);
+ libgamma_linux_drm_site_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- libgamma_w32gdi_site_destroy(this);
+ libgamma_w32_gdi_site_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
@@ -451,11 +451,11 @@ int libgamma_site_restore(libgamma_site_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_site_restore(this);
+ return libgamma_linux_drm_site_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_site_restore(this);
+ return libgamma_w32_gdi_site_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -500,11 +500,11 @@ int libgamma_partition_initialise(libgamma_partition_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_partition_initialise(this, site, partition);
+ return libgamma_linux_drm_partition_initialise(this, site, partition);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_partition_initialise(this, site, partition);
+ return libgamma_w32_gdi_partition_initialise(this, site, partition);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -543,12 +543,12 @@ void libgamma_partition_destroy(libgamma_partition_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- libgamma_drm_partition_destroy(this);
+ libgamma_linux_drm_partition_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- libgamma_w32gdi_partition_destroy(this);
+ libgamma_w32_gdi_partition_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
@@ -603,11 +603,11 @@ int libgamma_partition_restore(libgamma_partition_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_partition_restore(this);
+ return libgamma_linux_drm_partition_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_partition_restore(this);
+ return libgamma_w32_gdi_partition_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -652,11 +652,11 @@ int libgamma_crtc_initialise(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_initialise(this, partition, crtc);
+ return libgamma_linux_drm_crtc_initialise(this, partition, crtc);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_initialise(this, partition, crtc);
+ return libgamma_w32_gdi_crtc_initialise(this, partition, crtc);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -695,12 +695,12 @@ void libgamma_crtc_destroy(libgamma_crtc_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- libgamma_drm_crtc_destroy(this);
+ libgamma_linux_drm_crtc_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- libgamma_w32gdi_crtc_destroy(this);
+ libgamma_w32_gdi_crtc_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
@@ -755,11 +755,11 @@ int libgamma_crtc_restore(libgamma_crtc_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_restore(this);
+ return libgamma_linux_drm_crtc_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_restore(this);
+ return libgamma_w32_gdi_crtc_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -805,11 +805,11 @@ int libgamma_get_crtc_information(libgamma_crtc_information_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_get_crtc_information(this, crtc, fields);
+ return libgamma_linux_drm_get_crtc_information(this, crtc, fields);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_get_crtc_information(this, crtc, fields);
+ return libgamma_w32_gdi_get_crtc_information(this, crtc, fields);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -981,11 +981,11 @@ int libgamma_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_get_gamma_ramps(this, ramps);
+ return libgamma_linux_drm_crtc_get_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_get_gamma_ramps(this, ramps);
+ return libgamma_w32_gdi_crtc_get_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1029,11 +1029,11 @@ int libgamma_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_set_gamma_ramps(this, ramps);
+ return libgamma_linux_drm_crtc_set_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_set_gamma_ramps(this, ramps);
+ return libgamma_w32_gdi_crtc_set_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1078,11 +1078,11 @@ int libgamma_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_get_gamma_ramps32(this, ramps);
+ return libgamma_linux_drm_crtc_get_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_get_gamma_ramps32(this, ramps);
+ return libgamma_w32_gdi_crtc_get_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1126,11 +1126,11 @@ int libgamma_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_set_gamma_ramps32(this, ramps);
+ return libgamma_linux_drm_crtc_set_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_set_gamma_ramps32(this, ramps);
+ return libgamma_w32_gdi_crtc_set_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1175,11 +1175,11 @@ int libgamma_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_get_gamma_ramps64(this, ramps);
+ return libgamma_linux_drm_crtc_get_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_get_gamma_ramps64(this, ramps);
+ return libgamma_w32_gdi_crtc_get_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1223,11 +1223,11 @@ int libgamma_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_set_gamma_ramps64(this, ramps);
+ return libgamma_linux_drm_crtc_set_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_set_gamma_ramps64(this, ramps);
+ return libgamma_w32_gdi_crtc_set_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1272,11 +1272,11 @@ int libgamma_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_get_gamma_rampsf(this, ramps);
+ return libgamma_linux_drm_crtc_get_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_get_gamma_rampsf(this, ramps);
+ return libgamma_w32_gdi_crtc_get_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1320,11 +1320,11 @@ int libgamma_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_set_gamma_rampsf(this, ramps);
+ return libgamma_linux_drm_crtc_set_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_set_gamma_rampsf(this, ramps);
+ return libgamma_w32_gdi_crtc_set_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1369,11 +1369,11 @@ int libgamma_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_get_gamma_rampsd(this, ramps);
+ return libgamma_linux_drm_crtc_get_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_get_gamma_rampsd(this, ramps);
+ return libgamma_w32_gdi_crtc_get_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
@@ -1417,11 +1417,11 @@ int libgamma_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
- return libgamma_drm_crtc_set_gamma_rampsd(this, ramps);
+ return libgamma_linux_drm_crtc_set_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_W32_GDI
case GAMMA_METHOD_W32_GDI:
- return libgamma_w32gdi_crtc_set_gamma_rampsd(this, ramps);
+ return libgamma_w32_gdi_crtc_set_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS
case GAMMA_METHOD_QUARTZ_CORE_GRAPHICS:
diff --git a/src/gamma-drm.h b/src/gamma-linux-drm.h
index ddb0512..d8e9386 100644
--- a/src/gamma-drm.h
+++ b/src/gamma-linux-drm.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LIBGAMMA_GAMMA_DRM_H
#define LIBGAMMA_GAMMA_DRM_H
#ifndef HAVE_GAMMA_METHOD_DRM
# error Compiling gamma-drm without HAVE_GAMMA_METHOD_DRM
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_drm_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_linux_drm_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,15 +47,15 @@ void libgamma_drm_method_capabilities(libgamma_method_capabilities_t* restrict t
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_site_initialise(libgamma_site_state_t* restrict this,
- char* restrict site);
+int libgamma_linux_drm_site_initialise(libgamma_site_state_t* restrict this,
+ char* restrict site);
/**
* Release all resources held by a site state
*
* @param this The site state
*/
-void libgamma_drm_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_linux_drm_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_drm_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_linux_drm_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,15 +76,15 @@ int libgamma_drm_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_partition_initialise(libgamma_partition_state_t* restrict this,
- libgamma_site_state_t* restrict site, size_t partition);
+int libgamma_linux_drm_partition_initialise(libgamma_partition_state_t* restrict this,
+ libgamma_site_state_t* restrict site, size_t partition);
/**
* Release all resources held by a partition state
*
* @param this The partition state
*/
-void libgamma_drm_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_linux_drm_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_drm_partition_destroy(libgamma_partition_state_t* restrict this);
*
* @param this The partition state
*/
-void libgamma_drm_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_linux_drm_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_drm_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_linux_drm_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,15 +113,15 @@ int libgamma_drm_partition_restore(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_initialise(libgamma_crtc_state_t* restrict this,
- libgamma_partition_state_t* restrict partition, size_t crtc);
+int libgamma_linux_drm_crtc_initialise(libgamma_crtc_state_t* restrict this,
+ libgamma_partition_state_t* restrict partition, size_t crtc);
/**
* Release all resources held by a CRTC state
*
* @param this The CRTC state
*/
-void libgamma_drm_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_linux_drm_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_drm_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_drm_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_linux_drm_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_drm_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_linux_drm_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,8 +149,8 @@ int libgamma_drm_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_drm_get_crtc_information(libgamma_crtc_information_t* restrict this,
- libgamma_crtc_state_t* restrict crtc, int32_t fields);
+int libgamma_linux_drm_get_crtc_information(libgamma_crtc_information_t* restrict this,
+ libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
* Get current the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -160,8 +160,8 @@ int libgamma_drm_get_crtc_information(libgamma_crtc_information_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t* restrict ramps);
+int libgamma_linux_drm_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -171,8 +171,8 @@ int libgamma_drm_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t ramps);
+int libgamma_linux_drm_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t ramps);
/**
@@ -183,8 +183,8 @@ int libgamma_drm_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t* restrict ramps);
+int libgamma_linux_drm_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 32-bit gamma-depth version
@@ -194,8 +194,8 @@ int libgamma_drm_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t ramps);
+int libgamma_linux_drm_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t ramps);
/**
@@ -206,8 +206,8 @@ int libgamma_drm_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t* restrict ramps);
+int libgamma_linux_drm_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 64-bit gamma-depth version
@@ -217,8 +217,8 @@ int libgamma_drm_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t ramps);
+int libgamma_linux_drm_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t ramps);
/**
@@ -229,8 +229,8 @@ int libgamma_drm_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t* restrict ramps);
+int libgamma_linux_drm_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `float` version
@@ -240,8 +240,8 @@ int libgamma_drm_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t ramps);
+int libgamma_linux_drm_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t ramps);
/**
* Get current the gamma ramps for a CRTC, `double` version
@@ -251,8 +251,8 @@ int libgamma_drm_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t* restrict ramps);
+int libgamma_linux_drm_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `double` version
@@ -262,8 +262,8 @@ int libgamma_drm_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_drm_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t ramps);
+int libgamma_linux_drm_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t ramps);
#endif
@@ -15,12 +15,12 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_DRM_H
-#define LIBGAMMA_GAMMA_DRM_H
+#ifndef LIBGAMMA_GAMMA_LINUX_DRM_H
+#define LIBGAMMA_GAMMA_LINUX_DRM_H
-#ifndef HAVE_GAMMA_METHOD_DRM
-# error Compiling gamma-drm without HAVE_GAMMA_METHOD_DRM
+#ifndef HAVE_GAMMA_METHOD_LINUX_DRM
+# error Compiling gamma-linux-drm without HAVE_GAMMA_METHOD_LINUX_DRM
#endif